import { usePurchases } from "@/hooks/usePurchases";
import { useUsers } from "@/hooks/useUsers";
import { Avatar, AvatarFallback } from "@/components/ui/avatar";
import { formatCurrency } from "@/utils/format-currency";
import { useShop } from "@/hooks/useShop";

export function RecentSales() {
	const { data: purchases } = usePurchases();
	const {shop} = useShop();
	const { data: users } = useUsers();

	const recent = purchases
		?.slice() // copy to avoid mutating original
		.sort((a, b) => new Date(b.date_purchased).getTime() - new Date(a.date_purchased).getTime())
		.slice(0, 5) // take 5 most recent

	return (
		<div className="space-y-8">
			{recent?.map((purchase) => {
				const user = users?.find((u) => u.id === purchase.user_id);
				const initials = user
					? `${user.first_name?.[0] ?? "U"}${user.last_name?.[0] ?? ""}`
					: "??";
				const name = user
					? `${user.first_name ?? "Unknown"} ${user.last_name ?? ""}`
					: "Unknown User";
				const email = user?.email ?? "unknown@email.com";

				return (
					<div className="flex items-center gap-4" key={purchase.id}>
						<Avatar className="h-9 w-9">
							<AvatarFallback>{initials}</AvatarFallback>
						</Avatar>
						<div className="flex flex-1 flex-wrap items-center justify-between">
							<div className="space-y-1">
								<p className="text-sm font-medium leading-none">{name}</p>
								<p className="text-sm text-muted-foreground">{email}</p>
							</div>
							<div className="font-medium">+{formatCurrency(purchase.total, shop?.currency ?? "USD")}</div>
						</div>
					</div>
				);
			})}
		</div>
	);
}
